#
# spec file for package python-qpid
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-qpid
Version:        1.37.0
Release:        16.1
Summary:        Apache Qpid Python client library for AMQP
License:        Apache-2.0
Group:          Development/Libraries/Python
Url:            http://qpid.apache.org
Source0:        http://www.apache.org/dist/qpid/python/%{version}/qpid-python-%{version}.tar.gz
BuildRequires:  python
BuildRequires:  python-devel
BuildRequires:  python-xml
Provides:       %{name}-common = %{version}
Obsoletes:      %{name}-common < %{version}
%if 0%{?suse_version} >= 1200
BuildArch:      noarch
%endif

%description
The Apache Qpid Python client library for AMQP.

%files
%doc LICENSE.txt
%doc NOTICE.txt README.md examples
%dir %{python_sitelib}/qpid
%{python_sitelib}/qpid/messaging/
%{python_sitelib}/qpid/saslmech/
%{python_sitelib}/mllib
%{python_sitelib}/qpid/*.py*
%{python_sitelib}/qpid/specs
%{python_sitelib}/qpid/tests
%{_bindir}/qpid-python-test
%exclude %{_bindir}/qpid-python-test.bat
%if "%{python_version}" >= "2.6"
%{python_sitelib}/qpid_python-*.egg-info
%endif

%package -n qpid-tests
Summary:        Conformance tests for Apache Qpid
Group:          Development/Libraries/Python
Requires:       python-qpid >= 1.35.0
Requires:       python-qpid-qmf >= 1.35.0

%description -n qpid-tests
Conformance tests for Apache Qpid.

%files -n qpid-tests
%{python_sitelib}/qpid_tests/
%doc NOTICE.txt
%doc LICENSE.txt

%prep
%setup -q -n qpid-python-%{version}
cd ..

%build
CFLAGS="%{optflags}" python setup.py build

%install
python setup.py install \
    --skip-build \
    --prefix %{_prefix} \
    --install-purelib %{python_sitelib} \
    --root %{buildroot}

chmod +x %{buildroot}/%{python_sitelib}/qpid/codec.py
chmod +x %{buildroot}/%{python_sitelib}/qpid/tests/codec.py
chmod +x %{buildroot}/%{python_sitelib}/qpid/reference.py
chmod +x %{buildroot}/%{python_sitelib}/qpid/managementdata.py
chmod +x %{buildroot}/%{python_sitelib}/qpid/disp.py

%changelog
* Fri Jan 19 2018 fstrba@suse.com
- Upgrade to upstream version 1.37.0
  * Bugs fixed
    + QPID-2524 - Fails loading dtd in Python 2.6 on Ubuntu 9.10
  (Karmic) with "ValueError: unknown url type:
  /.../specs/amqp.0-10.dtd"
    + QPID-7809 - Python 0-10 messaging driver does not handle
    heartbeat timeouts, "assert rcv.received < rcv.impending"
    occurs
    + QPID-7833 - Batch file for Windows is missing from source
    distribution
    + QPID-7884 - Python client should not raise exception on
    close() after stop.
    + QPID-7317 - Deadlock on publish
    + QPID-7423 - [0-8...0-91] Chunk message content that exceeds
    the capacity of a single frame into multiple frames
    + QPID-7424 - [0-8..0-91] Consuming python client application
    is not notified of remotely closed connection
    + QPID-7588 - [Python Client 0-8..0-91] The received message
    ocasionally might not be dispatched into the application
    queue in timely manner
* Wed Feb 22 2017 fstrba@suse.com
- Upgrade to upstream version 1.35.0
  * New features and improvements
    + QPID-6475 - 08..09 Send connection.close before closing socket
    + QPID-6567 - Support producer side flow control in the
    0-8/9/9-1 Python client
    + QPID-6839 - When the Selector thread hits an unknown exception
    it should log the exception and traceback.
    + QPID-7053 - Exception Notifier Callback
  * Bugs fixed
    + QPID-6297 - Python client (qpid.messaging) raises KeyError
    instead of reconnecting
    + QPID-6326 - [ACL] Python client demands unnecessary
    permission / performs unnecessary actions
    + QPID-6405 - Python client does not report version to peer
    + QPID-6445 - Qpid python client hangs when message with routing
    key longer than 255 is sent (mutual recursion)
    + QPID-6473 - Remove remaining Python <= 2.5 raise syntax (i.e.
    raise "...") from connection08.py
    + QPID-6474 - 08..09 Python client connection leaks threads
    + QPID-7064 - Document Asynchronous Error Notification API on
    Connection, Session, Receiver, and Sender objects
    + QPID-7222 - Python test
    qpid_tests.broker_0_10.message.MessageTests.test_release_order
    fails sporadically against java broker
    + QPID-7251 - [Python Client for AMQP 0-8...0-91] Setting of
    SASL mechanism (other then PLAIN) explicitly does not work in
    python client for AMQP 0-8...0-91
    + QPID-7258 - [Python Client for AMQP 0-8...0-9-1] Perform
    hostname verification of ssl/tls connections
    + QPID-7259 -
    qpid_tests.broker_0_10.message.MessageTests.test_window_flow_messages
    occasionally fails against the Java Broker
* Thu Jul 16 2015 seife+obs@b1-systems.com
- fix "bad %%if condition" for non-SUSE distributions
* Thu Mar 26 2015 fstrba@suse.com
- Add LICENSE.txt file to installed documentation
* Wed Mar 25 2015 fstrba@suse.com
- Upgrade to upstream version 0.32
* Wed Feb 25 2015 fstrba@suse.com
- Upgrade to upstream version 0.30
- Remove integrated patch:
  * 0001-QPID-5790-avoid-use-of-poll-if-select-is-monkey-patc.patch
* Thu Jul 24 2014 fstrba@suse.com
- Upgrade to upstream version 0.28
- Added upstream patch to avoid use of poll if select is monkey
  patched by Eventlet/Greenthreads
  * 0001-QPID-5790-avoid-use-of-poll-if-select-is-monkey-patc.patch
* Mon Apr 14 2014 fstrba@suse.com
- Upgrade to upstream version 0.26
* Tue Oct  8 2013 fridrich.strba@suse.com
- Fixing build with python that does not have noarch macros
* Mon Sep 30 2013 fridrich.strba@suse.com
- Add BuildRoot line to fix build on older systems
* Fri Sep 20 2013 fridrich.strba@suse.com
- Initial package based on Fedora's python-qpid
